/*-----------------------------------------------------------------------------*/
/*  FrvMath.h by I. Ferrante, I. Fiori, F. Marion, B.Mours  Jul 15, 2002       */
/*-----------------------------------------------------------------------------*/

#ifndef FRVMATH
#define FRVMATH

#define _POSIX_SOURCE 
#include "FrameL.h"
#include "FrvCopy.h"

#ifdef __cplusplus
extern "C" {
#endif

#define FRVTWOPI  6.2831853071795864769

struct FrvStat {

  double decay;
  double decayTime;
  long   nDecay;
  double dt;
  double meanA;
  double rmsA;
  double x2A;
  struct FrVect *mean;
  struct FrVect *rms;

};

typedef struct FrvStat FrvStat;

void     FrvStatFree(FrvStat *stat);
FrvStat* FrvStatNew();
FrvStat* FrvStatProc(FrvStat *stat, FrVect *vect);
FrvStat* FrvStatProcV(FrvStat *stat, double input);
void     FrvStatReset(FrvStat *stat);
void     FrvStatSetDecay(FrvStat* stat, double decay);
void     FrvStatSetDecayTime(FrvStat* stat, double decayTime);

FrVect *FrvAdd(FrVect *vect1, FrVect *vect2, FrVect *vectOut, char* newName);
FrVect *FrvBias(FrVect *vect1, double bias, FrVect *vectOut);
FrVect *FrvCombine2(double s1, FrVect *vect1,
                    double s2, FrVect *vect2,
                    FrVect *vectOut, char* newName);
FrVect *FrvCombine(int nVect,
                   ...);
int     FrvDelta  (FrVect *vect1, double *delta, double *previous);
FrVect *FrvDivide (FrVect *vect1, FrVect *vect2,FrVect *vectOut,char* newName);
FrVect *FrvFlatten(FrVect *vect1, FrVect *vectOut); 
FrVect* FrvIntegrate(FrVect *inVect, int n, char* newName);
int     FrvMean   (FrVect *vect1, double *mean);
FrVect *FrvModulus(FrVect *vect1, FrVect *vectOut, char *newName);
FrVect *FrvMult   (FrVect *vect1, FrVect *vect2,FrVect *vectOut,char* newName);
FrVect *FrvMultConj(FrVect *vect1, FrVect *vect2,FrVect *vectOut,char* newName);
FrVect *FrvPhase  (FrVect *vect1, FrVect *vectOut, char *newName);
int     FrvRms    (FrVect *vect1, double *mean, double *rms);
FrVect *FrvScale  (double scale, FrVect *vect1,FrVect *vectOut, char* newName);
FrVect *FrvSub    (FrVect *vect1,FrVect *vect2,FrVect *vectOut, char* newName);
FrVect *FrvZeroMean(FrVect *vect1,FrVect *vectOut); 

#ifdef __cplusplus
}
#endif

#endif
